@@ -12,6 +12,11 @@
 # limitations under the License.
 
 DEFAULT_NAMESPACE = "aws-embedded-metrics"
-MAX_DIMENSION_SET_SIZE = 30
 MAX_METRICS_PER_EVENT = 100
 MAX_DATAPOINTS_PER_METRIC = 100
+MAX_DIMENSION_SET_SIZE = 30
+MAX_DIMENSION_NAME_LENGTH = 250
+MAX_DIMENSION_VALUE_LENGTH = 1024
+MAX_METRIC_NAME_LENGTH = 1024
+MAX_NAMESPACE_LENGTH = 256
+VALID_NAMESPACE_REGEX = '^[a-zA-Z0-9._#:/-]+$'
