@@ -16,6 +16,7 @@ from aws_embedded_metrics import constants, utils
 from aws_embedded_metrics.config import get_config
 from aws_embedded_metrics.logger.metric import Metric
 from aws_embedded_metrics.validator import validate_dimension_set, validate_metric
+from aws_embedded_metrics.storage_resolution import StorageResolution
 from typing import List, Dict, Any, Set
 
 
@@ -39,8 +40,9 @@ class MetricsContext(object):
         self.metrics: Dict[str, Metric] = {}
         self.should_use_default_dimensions = True
         self.meta: Dict[str, Any] = {"Timestamp": utils.now()}
+        self.metric_name_and_resolution_map: Dict[str, StorageResolution] = {}
 
-    def put_metric(self, key: str, value: float, unit: str = None) -> None:
+    def put_metric(self, key: str, value: float, unit: str = None, storage_resolution: StorageResolution = StorageResolution.STANDARD) -> None:
         """
         Adds a metric measurement to the context.
         Multiple calls using the same key will be stored as an
@@ -49,13 +51,14 @@ class MetricsContext(object):
         context.put_metric("Latency", 100, "Milliseconds")
         ```
         """
-        validate_metric(key, value, unit)
+        validate_metric(key, value, unit, storage_resolution, self.metric_name_and_resolution_map)
         metric = self.metrics.get(key)
         if metric:
             # TODO: we should log a warning if the unit has been changed
             metric.add_value(value)
         else:
-            self.metrics[key] = Metric(value, unit)
+            self.metrics[key] = Metric(value, unit, storage_resolution)
+        self.metric_name_and_resolution_map[key] = storage_resolution
 
     def put_dimensions(self, dimension_set: Dict[str, str]) -> None:
         """
